
--[[

name:   Sample Splash Screen
vers:   1.0.3
desc:   A simple splash screen with a logo that starts small, 
        zooms in until it is  full size, waits  for a second, 
        then  zooms out by  growing in size and  fading away. 
        Each phase is accompanied  by a strange sound sample.
auth:   by Cliff Earl, Antix Development
date:   June 2016
legal:  Distribute freely but please leave my credits intact.
histo:  v1.0.1
        Added  the  ability to  skip  the  splash  screen  by 
        touching the display if the global variable debugging 
        is true (see first line of init())
        v1.0.2
        Sound output now takes into account PREFS.soundVolume
        v1.0.3
        - Removed the debugging  stuff since it is  always best 
          to allow the end user to skip these things :)
        - The Antix scene has now been renamed as MySplash
--]]

MySplash = Core.class(Sprite)

function MySplash:init(userData) -- GoGo
  
  self.onComplete = userData.onComplete
  
  local width, height = application:getContentWidth(), application:getContentHeight()
  
  self.enterSound = Sound.new("mysplash/enter.wav") -- Funky sounds
  self.exitSound = Sound.new("mysplash/leave.wav")
  self.channel = nil

  local logo = Bitmap.new(Texture.new("mysplash/logo.png", true) )
  logo:setAnchorPoint(0.5, 0.5)
  
  local destX = width + logo:getWidth()
  
  logo:setPosition(width + logo:getWidth(), height * 0.5) -- Place logo off screen to right
  self.ratio = width / logo:getWidth() -- Calculate scale
  self:addChild(logo)
  
  self.destX = width + logo:getWidth()
  self.ratio = 3555
  
  self.width = width
  
  self.phase = "enter"
  self.elapsed = 0
  self.speed = 1
  
  self:addEventListener("enterBegin", self.onTransitionInBegin, self)
  self:addEventListener("enterEnd", self.onTransitionInEnd, self)
  self:addEventListener("exitBegin", self.onTransitionOutBegin, self)
  self:addEventListener("exitEnd", self.onTransitionOutEnd, self)
end

function MySplash:onTouch(e)
  self.onComplete()
--  SCENEMANAGER:changeScene("Game", 1, SceneManager.fade, easing.linear)
end

function MySplash:onTransitionInEnd() -- Add listeners, start logic
  local prefs = PREFS
  print("enter volume =", 1 * prefs.soundVolume)
  self.channel = self.enterSound:play(1, 1.6)
  self.channel:setVolume(1 * prefs.soundVolume)
  self:addEventListener(Event.ENTER_FRAME, self.update, self)
end

function MySplash:onTransitionInBegin() -- Initialize variables
  self:addEventListener(Event.TOUCHES_BEGIN, self.onTouch, self)
end

function MySplash:onTransitionOutBegin() -- Stoip Timers, remove listeners
  self:removeEventListener(Event.TOUCHES_BEGIN, self.onTouch, self)
  self:removeEventListener(Event.ENTER_FRAME, self.update, self)
end

function MySplash:onTransitionOutEnd() -- Gone from stage, so cleanup
  self:removeEventListener("enterBegin", self.onTransitionInBegin, self)
  self:removeEventListener("enterEnd", self.onTransitionInEnd, self)
  self:removeEventListener("exitBegin", self.onTransitionOutBegin, self)
  self:removeEventListener("exitEnd", self.onTransitionOutEnd, self)
  
  local logo = self:getChildAt(1)
  logo:removeFromParent()
  logo = nil
  
  self.elapsed = nil
  self.speed = nil
  
  if self.channel then self.channel:stop() end
  self.channel = nil
  self.enterSound = nil
  self.exitSound = nil
end

-- Update every frame
function MySplash:update(e)
  local elapsed = self.elapsed + (e.deltaTime * self.speed)
  
  local logo = self:getChildAt(1)
  
  local phase = self.phase
  
  if phase == "enter" then -- Zoom in until full size
    logo:setRotation(self.ratio * elapsed)
    logo:setX(self.destX - ((self.destX - (self.width * 0.5)) * elapsed))
    if elapsed >= 1 then
      self.channel:stop()
      self.phase = "wait"
    end
    
  elseif phase == "wait" then -- Wait a bit (1.5 seconds to be exact)
    if elapsed >= 2.5 then
      local prefs = PREFS
      self.channel = self.exitSound:play()
      self.channel:setVolume(1 * prefs.soundVolume)
      self.ratio = 1
      self.phase = "leave"
    end
    
  else -- Must be leaving if we arrived here
    self.speed = self.speed + 2
    local alpha = logo:getAlpha() - 0.018
    if alpha <= 0 then
      
    self.onComplete() -- execute onComplete function
    
    else
      logo:setAlpha(alpha)
      logo:setScale(self.ratio * (elapsed - 1.5) )
    end
  end
  
  self.elapsed = elapsed
end
